/*****************************************************************************
 * Open MCT, Copyright (c) 2014-2022, United States Government
 * as represented by the Administrator of the National Aeronautics and Space
 * Administration. All rights reserved.
 *
 * Open MCT is licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 * Open MCT includes source code licensed under additional open source
 * licenses. See the Open Source Licenses file (LICENSES.md) included with
 * this source code distribution or the Licensing information page available
 * at runtime from the About dialog for additional information.
 *****************************************************************************/

export function getValidatedData(domainObject) {
    let sourceMap = domainObject.sourceMap;
    let body = domainObject.selectFile?.body;
    let json = {};
    if (typeof body === 'string') {
        try {
            json = JSON.parse(body);
        } catch (e) {
            return json;
        }
    } else if (body !== undefined) {
        json = body;
    }

    if (sourceMap !== undefined && sourceMap.activities !== undefined && sourceMap.groupId !== undefined) {
        let mappedJson = {};
        json[sourceMap.activities].forEach((activity) => {
            if (activity[sourceMap.groupId]) {
                const groupIdKey = activity[sourceMap.groupId];
                let groupActivity = {
                    ...activity
                };

                if (sourceMap.start) {
                    groupActivity.start = activity[sourceMap.start];
                }

                if (sourceMap.end) {
                    groupActivity.end = activity[sourceMap.end];
                }

                if (!mappedJson[groupIdKey]) {
                    mappedJson[groupIdKey] = [];
                }

                mappedJson[groupIdKey].push(groupActivity);
            }
        });

        return mappedJson;
    } else {
        return json;
    }
}
